==> v0.2.tar.gz: qqsp/Qqsp.en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.cpp" line="51"/>
        <source>ToolBar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="264"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="449"/>
        <source>&amp;Quest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="452"/>
        <source>Open game...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="457"/>
        <source>Restart game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="465"/>
        <source>Exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="471"/>
        <source>&amp;Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="474"/>
        <source>Open saved game...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="478"/>
        <source>Save game...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="484"/>
        <source>&amp;Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="487"/>
        <source>Show / Hide</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="512"/>
        <source>Captions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="542"/>
        <source>Sound volume...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="546"/>
        <source>Window / Fullscreen mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="554"/>
        <source>Display HTML code as plain text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="565"/>
        <source>Options...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="571"/>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="574"/>
        <source>About...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="582"/>
        <source>Objects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="594"/>
        <source>Actions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="606"/>
        <source>Additional desc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="615"/>
        <source>Input area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="772"/>
        <source>Select game file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="772"/>
        <source>QSP games (*.qsp *.gam)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="callbacks_gui.cpp" line="294"/>
        <source>Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="callbacks_gui.cpp" line="382"/>
        <location filename="mainwindow.cpp" line="793"/>
        <source>Select saved game file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="callbacks_gui.cpp" line="382"/>
        <location filename="callbacks_gui.cpp" line="400"/>
        <location filename="mainwindow.cpp" line="793"/>
        <location filename="mainwindow.cpp" line="808"/>
        <source>Saved game files (*.sav)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="callbacks_gui.cpp" line="400"/>
        <location filename="mainwindow.cpp" line="808"/>
        <source>Select file to save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="839"/>
        <source>, </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="840"/>
        <source>&lt;h2&gt;Qqsp&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2017, S.&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="842"/>
        <source>&lt;p&gt;Application version: %1&lt;br&gt;QSP library version: %2&lt;br&gt;Application compilation date: %3&lt;br&gt;Library compilation date: %4&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="843"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="optionsdialog.ui" line="17"/>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="25"/>
        <source>Use custom font size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="39"/>
        <source>Use custom font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="68"/>
        <location filename="optionsdialog.ui" line="124"/>
        <location filename="optionsdialog.ui" line="204"/>
        <location filename="optionsdialog.ui" line="253"/>
        <source>Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="77"/>
        <source>Custom background color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="133"/>
        <source>Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="143"/>
        <source>Custom text color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="150"/>
        <source>Custom link color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="157"/>
        <source>Autostart last game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="262"/>
        <source>Separate config per game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="299"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="306"/>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="main.cpp" line="16"/>
        <source>__LANGNAME__</source>
        <translation>English</translation>
    </message>
    <message>
        <location filename="main.cpp" line="17"/>
        <location filename="mainwindow.cpp" line="89"/>
        <source>__LANGID__</source>
        <translation>en_US</translation>
    </message>
</context>
<context>
    <name>QspImgCanvas</name>
    <message>
        <location filename="qspimgcanvas.cpp" line="9"/>
        <source>Image</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QspMsgDlg</name>
    <message>
        <location filename="qspmsgdlg.cpp" line="32"/>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>__LANG__</name>
    <message>
        <location filename="optionsdialog.cpp" line="46"/>
        <location filename="optionsdialog.cpp" line="55"/>
        <source>__LANGNAME__</source>
        <translation>English</translation>
    </message>
    <message>
        <location filename="optionsdialog.cpp" line="46"/>
        <location filename="optionsdialog.cpp" line="55"/>
        <source>__LANGID__</source>
        <translation>en_US</translation>
    </message>
</context>
</TS>

==> v0.5.tar.gz: qqsp/Qqsp.en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.cpp" line="52"/>
        <source>ToolBar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="267"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="449"/>
        <source>&amp;Quest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="452"/>
        <source>Open game...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="457"/>
        <source>Restart game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="465"/>
        <source>Exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="471"/>
        <source>&amp;Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="474"/>
        <source>Open saved game...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="478"/>
        <source>Save game...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="484"/>
        <source>&amp;Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="487"/>
        <source>Show / Hide</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="517"/>
        <source>Captions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="547"/>
        <source>Window / Fullscreen mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="555"/>
        <source>Display HTML code as plain text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="566"/>
        <source>Options...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="572"/>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="575"/>
        <source>About...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="590"/>
        <source>Main desc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="596"/>
        <source>Objects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="608"/>
        <source>Actions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="621"/>
        <source>Additional desc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="634"/>
        <source>Input area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="792"/>
        <source>Select game file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="792"/>
        <source>QSP games (*.qsp *.gam)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="callbacks_gui.cpp" line="259"/>
        <source>Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="callbacks_gui.cpp" line="313"/>
        <source>Input data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="callbacks_gui.cpp" line="347"/>
        <location filename="mainwindow.cpp" line="813"/>
        <source>Select saved game file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="callbacks_gui.cpp" line="347"/>
        <location filename="callbacks_gui.cpp" line="365"/>
        <location filename="mainwindow.cpp" line="813"/>
        <location filename="mainwindow.cpp" line="828"/>
        <source>Saved game files (*.sav)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="callbacks_gui.cpp" line="365"/>
        <location filename="mainwindow.cpp" line="828"/>
        <source>Select file to save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="859"/>
        <source>, </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="860"/>
        <source>&lt;h2&gt;Qqsp&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2017, S.&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="862"/>
        <source>&lt;p&gt;Application version: %1&lt;br&gt;QSP library version: %2&lt;br&gt;Application compilation date: %3&lt;br&gt;Library compilation date: %4&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="863"/>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="optionsdialog.ui" line="17"/>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="25"/>
        <source>Use custom font size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="39"/>
        <source>Use custom font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="68"/>
        <location filename="optionsdialog.ui" line="124"/>
        <location filename="optionsdialog.ui" line="204"/>
        <location filename="optionsdialog.ui" line="253"/>
        <source>Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="77"/>
        <source>Custom background color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="133"/>
        <source>Language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="143"/>
        <source>Custom text color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="150"/>
        <source>Custom link color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="157"/>
        <source>Autostart last game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="262"/>
        <source>Separate config per game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="269"/>
        <source>Sound volume</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="316"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="323"/>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="main.cpp" line="16"/>
        <source>__LANGNAME__</source>
        <translation>English</translation>
    </message>
    <message>
        <location filename="main.cpp" line="17"/>
        <location filename="mainwindow.cpp" line="89"/>
        <source>__LANGID__</source>
        <translation>en_US</translation>
    </message>
</context>
<context>
    <name>QspImgCanvas</name>
    <message>
        <location filename="qspimgcanvas.cpp" line="9"/>
        <source>Image</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QspMsgDlg</name>
    <message>
        <location filename="qspmsgdlg.cpp" line="32"/>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>__LANG__</name>
    <message>
        <location filename="optionsdialog.cpp" line="47"/>
        <location filename="optionsdialog.cpp" line="56"/>
        <source>__LANGNAME__</source>
        <translation>English</translation>
    </message>
    <message>
        <location filename="optionsdialog.cpp" line="47"/>
        <location filename="optionsdialog.cpp" line="56"/>
        <source>__LANGID__</source>
        <translation>en_US</translation>
    </message>
</context>
</TS>
